Date: 2023-04-26
Module: I/O
Summary: Initial Release Note
Version: 1.0.0

## New Features
- Bootstrap module versioning

## Enhancements
- Allow for an automatic view resource created from the view serializer for export

## Bugfixes
./.
